==> noahs-2.0.7.tar.gz: noahs/src/Plugin/Control/ControlNoahsBackgroundImage.php <==
<?php 

namespace Drupal\noahs_page_builder\Plugin\Control;

use Drupal\noahs_page_builder\Annotation\ControlPlugin;
use Drupal\noahs_page_builder\Plugin\Control\ControlBase;
use \Drupal\noahs_page_builder\Controller\NoahsController;

/**
 * @ControlPlugin(
 *   id = "noahs_background_image",
 *   label = @Translation("Bg image")
 * )
 */
class ControlNoahsBackgroundImage extends ControlBase{
	
	public function get_type() {
		return 'noahs_background_image';
	}

	public function content_template(array $params = []) {
		$data = $params['data'] ?? null;
    	$name = $params['name'] ?? null;
    	$value = $params['value'] ?? null;

		$id = $data['wid'];
		$image_styles = NoahsController::getImageStyle();
	
		$image = !empty($value['background_image']['thumbnail']) ? $value['background_image']['thumbnail'] : '/' . NOAHS_PAGE_BUILDER_PATH . '/assets/img/no-image-thumbnail.jpg';
	
		$field_names = [
			'Background Position' => 'background_position',
			'Background repeat' => 'background_repeat',
			'Background Attachment' => 'background_attachment',
			'Background size' => 'background_size'
		];
	
		$options = [
			'background_position' => [
				'' => 'Center Center',
				'center top' => 'Center Top',
				'center right' => 'Center Right',
				'center bottom' => 'Center Bottom',
				'left top' => 'Left Top',
				'left center' => 'Left Center',
				'left bottom' => 'Left Bottom',
				'right top' => 'Right Top',
				'right center' => 'Right Center',
				'right bottom' => 'Right Bottom'
			],
			'background_repeat' => [
				'' => 'No Repeat',
				'repeat' => 'Repeat',
				'repeat-x' => 'Repeat X',
				'repeat-y' => 'Repeat Y'
			],
			'background_attachment' => [
				'' => 'Default',
				'scroll' => 'Scroll',
				'fixed' => 'Fixed'
			],
			'background_size' => [
				'' => 'Default',
				'cover' => 'Cover',
				'contain' => 'Contain'
			]
		];
	
		$nameBase = $name . '[background_image]';
		$element_id = preg_replace('/[\[\]]+/', '_', $name);
	
		$html = '<div class="field_group mt-3">';
		$html .= '<div class="field_group field_element mb-3">';
	
		$html .= '<div class="mb-3 background-image-field">';
		$html .= '<div class="media-preview-actions d-flex justify-content-center align-items-center mb-3">';
	
		$html .= '<img class="background-thumbnail-image" src="' . $image . '" alt="Thumbnail">';
		$html .= '<input type="hidden" name="' . $name . '[background_image][fid]" id="' . $element_id . '" value="' . (!empty($value['background_image']['fid']) ? $value['background_image']['fid'] : '') . '" class="form-control background-fid" field-settings>';
		$html .= '<input type="hidden" name="' . $name . '[background_image][thumbnail]" value="' . (!empty($value['background_image']['thumbnail']) ? $value['background_image']['thumbnail'] : '') . '" class="form-control background-thumbnail" field-settings>';
		$html .= '<input type="hidden" name="' . $name . '[background_image][original]" value="' . (!empty($value['background_image']['original']) ? $value['background_image']['original'] : '') . '" class="form-control background-original" field-settings>';
		$html .= '<div class="btn-group position-absolute d-flex justify-content-between w-100">';
		$html .= '<button class="btn btn-primary media-uploadbg_image area_tooltip" title="' . t('Add/change Image') . '" data-element-id="' . $element_id . '"><i class="fa-solid fa-circle-plus"></i></button>';
		$html .= '<button class="btn btn-danger media-removebg_image area_tooltip" title="' . t('Remove Image') . '"><i class="fa-solid fa-trash"></i></button>';
		$html .= '</div>';
		$html .= '</div>';
	
		$html .= '<div class="mb-3">';
		$html .= '<label for="">' . t('Use Media Token Field') . '</label>';
		$html .= '<input type="text" name="' . $name . '[token_media]" value="' . (!empty($value['token_media']) ? $value['token_media'] : '') . '" class="form-control" field-settings>';
		$html .= '</div>';
		$html .= '<div class="nohas-field-description mb-4">' . t('This is not available on token module, copy and replace your entity, field and style: [node:field_featured_image:entity:field_media_image:og_image_1200x630]') . '</div>';
	
		$html .= '<div class="field_group field_item mb-3">';
		$html .= '<label for="noahs_page_builder_background_image_style">Image Style</label>';
		$html .= '<select name="' . $name . '[image_style]" class="form-control noahs-regenerate-design" field-settings>';
		foreach ($image_styles as $k => $style) {
			$selected = (!empty($value['image_style']) && $value['image_style'] === $k) ? 'selected' : '';
			$html .= '<option value="' . $k . '" ' . $selected . '>' . $style . '</option>';
		}
		$html .= '</select>';
		$html .= '</div>';
		$html .= '</div>';



		foreach ($field_names as $label => $field_name) {
			$html .= '<div class="field_group field_item mb-3">';
			$html .= '<label for="noahs_page_builder_' . $field_name . '">' . $label . '</label>';
			$html .= '<select name="' . $nameBase . '[' . $field_name . ']" data-style-css="' . str_replace('_', '-', $field_name) . '" class="form-control" field-settings>';
			foreach ($options[$field_name] as $k => $title) {
				$selected = (!empty($value['background_image'][$field_name]) && $value['background_image'][$field_name] === $k) ? ' selected' : '';
				$html .= '<option value="' . $k . '" ' . $selected . '>' . $title . '</option>';
			}
			$html .= '</select>';
			$html .= '</div>';
		}
		$html .= '<div class="mb-3">';
		$html .= '<label for="">' . t('Background Size Custom') . '</label>';
		$html .= '<input type="text" name="' . $name . '[background_size_custom]" value="' . (!empty($value['background_size_custom']) ? $value['background_size_custom'] : '') . '" class="form-control" field-settings>';
		$html .= '<div class="nohas-field-description mb-4">' . t('Example: 100px 100px') . '</div>';

		$html .= '</div>';
		$html .= '</div>';
		$html .= '</div>';
	
		return $html;
	}
	

	public function get_default_settings() {
		return [
			'input_type' => 'noahs_background_image',
			'placeholder' => '',
			'title' => '',
		];
	}
}

==> noahs-2.1.3.tar.gz: noahs/src/Plugin/Control/ControlNoahsBackgroundImage.php <==
<?php 

namespace Drupal\noahs_page_builder\Plugin\Control;

use Drupal\noahs_page_builder\Annotation\ControlPlugin;
use Drupal\noahs_page_builder\Plugin\Control\ControlBase;
use \Drupal\noahs_page_builder\Controller\NoahsController;

/**
 * @ControlPlugin(
 *   id = "noahs_background_image",
 *   label = @Translation("Bg image")
 * )
 */
class ControlNoahsBackgroundImage extends ControlBase{
	
	public function get_type() {
		return 'noahs_background_image';
	}

	public function content_template(array $params = []) {
		$data = $params['data'] ?? null;
    	$name = $params['name'] ?? null;
    	$value = $params['value'] ?? null;

		$id = $data['wid'];
		$image_styles = $this->getImageStyles();
	
		$image = !empty($value['background_image']['thumbnail']) ? $value['background_image']['thumbnail'] : '/' . NOAHS_PAGE_BUILDER_PATH . '/assets/img/no-image-thumbnail.jpg';
	
		$field_names = [
			'Background Position' => 'background_position',
			'Background repeat' => 'background_repeat',
			'Background Attachment' => 'background_attachment',
			'Background size' => 'background_size'
		];
	
		$options = [
			'background_position' => [
				'' => 'Center Center',
				'center top' => 'Center Top',
				'center right' => 'Center Right',
				'center bottom' => 'Center Bottom',
				'left top' => 'Left Top',
				'left center' => 'Left Center',
				'left bottom' => 'Left Bottom',
				'right top' => 'Right Top',
				'right center' => 'Right Center',
				'right bottom' => 'Right Bottom'
			],
			'background_repeat' => [
				'' => 'No Repeat',
				'repeat' => 'Repeat',
				'repeat-x' => 'Repeat X',
				'repeat-y' => 'Repeat Y'
			],
			'background_attachment' => [
				'' => 'Default',
				'scroll' => 'Scroll',
				'fixed' => 'Fixed'
			],
			'background_size' => [
				'' => 'Default',
				'cover' => 'Cover',
				'contain' => 'Contain'
			]
		];
	
		$nameBase = $name . '[background_image]';
		$element_id = preg_replace('/[\[\]]+/', '_', $name);
	
		$html = '<div class="field_group mt-3">';
		$html .= '<div class="field_group field_element mb-3">';
	
		$html .= '<div class="mb-3 background-image-field">';
		$html .= '<div class="media-preview-actions d-flex justify-content-center align-items-center mb-3">';
	
		$html .= '<img class="background-thumbnail-image" src="' . $image . '" alt="Thumbnail">';
		$html .= '<input type="hidden" name="' . $name . '[background_image][fid]" id="' . $element_id . '" value="' . (!empty($value['background_image']['fid']) ? $value['background_image']['fid'] : '') . '" class="form-control background-fid" field-settings>';
		$html .= '<input type="hidden" name="' . $name . '[background_image][thumbnail]" value="' . (!empty($value['background_image']['thumbnail']) ? $value['background_image']['thumbnail'] : '') . '" class="form-control background-thumbnail" field-settings>';
		$html .= '<input type="hidden" name="' . $name . '[background_image][original]" value="' . (!empty($value['background_image']['original']) ? $value['background_image']['original'] : '') . '" class="form-control background-original" field-settings>';
		$html .= '<div class="btn-group position-absolute d-flex justify-content-between w-100">';
		$html .= '<button class="btn btn-primary media-uploadbg_image area_tooltip" title="' . t('Add/change Image') . '" data-element-id="' . $element_id . '"><i class="fa-solid fa-circle-plus"></i></button>';
		$html .= '<button class="btn btn-danger media-removebg_image area_tooltip" title="' . t('Remove Image') . '"><i class="fa-solid fa-trash"></i></button>';
		$html .= '</div>';
		$html .= '</div>';
	
		$html .= '<div class="mb-3">';
		$html .= '<label for="">' . t('Use Media Token Field') . '</label>';
		$html .= '<input type="text" name="' . $name . '[token_media]" value="' . (!empty($value['token_media']) ? $value['token_media'] : '') . '" class="form-control" field-settings>';
		$html .= '</div>';
		$html .= '<div class="nohas-field-description mb-4">' . t('This is not available on token module, copy and replace your entity, field and style: [node:field_featured_image:entity:field_media_image:og_image_1200x630]') . '</div>';
	
		$html .= '<div class="field_group field_item mb-3">';
		$html .= '<label for="noahs_page_builder_background_image_style">Image Style</label>';
		$html .= '<select name="' . $name . '[image_style]" class="form-control noahs-regenerate-design" field-settings>';
		foreach ($image_styles as $k => $style) {
			$selected = (!empty($value['image_style']) && $value['image_style'] === $k) ? 'selected' : '';
			$html .= '<option value="' . $k . '" ' . $selected . '>' . $style . '</option>';
		}
		$html .= '</select>';
		$html .= '</div>';
		$html .= '</div>';



		foreach ($field_names as $label => $field_name) {
			$html .= '<div class="field_group field_item mb-3">';
			$html .= '<label for="noahs_page_builder_' . $field_name . '">' . $label . '</label>';
			$html .= '<select name="' . $nameBase . '[' . $field_name . ']" data-style-css="' . str_replace('_', '-', $field_name) . '" class="form-control" field-settings>';
			foreach ($options[$field_name] as $k => $title) {
				$selected = (!empty($value['background_image'][$field_name]) && $value['background_image'][$field_name] === $k) ? ' selected' : '';
				$html .= '<option value="' . $k . '" ' . $selected . '>' . $title . '</option>';
			}
			$html .= '</select>';
			$html .= '</div>';
		}
		$html .= '<div class="mb-3">';
		$html .= '<label for="">' . t('Background Size Custom') . '</label>';
		$html .= '<input type="text" name="' . $name . '[background_size_custom]" value="' . (!empty($value['background_size_custom']) ? $value['background_size_custom'] : '') . '" class="form-control" field-settings>';
		$html .= '<div class="nohas-field-description mb-4">' . t('Example: 100px 100px') . '</div>';

		$html .= '</div>';
		$html .= '</div>';
		$html .= '</div>';
	
		return $html;
	}
	

	public function get_default_settings() {
		return [
			'input_type' => 'noahs_background_image',
			'placeholder' => '',
			'title' => '',
		];
	}
}
